==> lambdaelasticsearchkibana-1.94.0-sources.jar: software/amazon/awsconstructs/services/lambdaelasticsearchkibana/LambdaToElasticSearchAndKibanaProps.java <==
package software.amazon.awsconstructs.services.lambdaelasticsearchkibana;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.26.0 (build 7d76e02)", date = "2021-04-02T01:59:45.250Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdaelasticsearchkibana.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-elasticsearch-kibana.LambdaToElasticSearchAndKibanaProps")
@software.amazon.jsii.Jsii.Proxy(LambdaToElasticSearchAndKibanaProps.Jsii$Proxy.class)
public interface LambdaToElasticSearchAndKibanaProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Cognito & ES Domain Name.
     * <p>
     * Default: - None
     */
    @org.jetbrains.annotations.NotNull java.lang.String getDomainName();

    /**
     * Optional Cognito Domain Name, if provided it will be used for Cognito Domain, and domainName will be used for the Elasticsearch Domain.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable java.lang.String getCognitoDomainName() {
        return null;
    }

    /**
     * Whether to create recommended CloudWatch alarms.
     * <p>
     * Default: - Alarms are created
     */
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getCreateCloudWatchAlarms() {
        return null;
    }

    /**
     * Optional Name for the ElasticSearch domain endpoint environment variable set for the Lambda function.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable java.lang.String getDomainEndpointEnvironmentVariableName() {
        return null;
    }

    /**
     * Optional user provided props to override the default props for the Elasticsearch Service.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.elasticsearch.CfnDomainProps getEsDomainProps() {
        return null;
    }

    /**
     * Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
        return null;
    }

    /**
     * User provided props to override the default props for the Lambda function.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LambdaToElasticSearchAndKibanaProps}
     */
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LambdaToElasticSearchAndKibanaProps}
     */
    public static final class Builder implements software.amazon.jsii.Builder<LambdaToElasticSearchAndKibanaProps> {
        private java.lang.String domainName;
        private java.lang.String cognitoDomainName;
        private java.lang.Boolean createCloudWatchAlarms;
        private java.lang.String domainEndpointEnvironmentVariableName;
        private software.amazon.awscdk.services.elasticsearch.CfnDomainProps esDomainProps;
        private software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;

        /**
         * Sets the value of {@link LambdaToElasticSearchAndKibanaProps#getDomainName}
         * @param domainName Cognito & ES Domain Name. This parameter is required.
         * @return {@code this}
         */
        public Builder domainName(java.lang.String domainName) {
            this.domainName = domainName;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToElasticSearchAndKibanaProps#getCognitoDomainName}
         * @param cognitoDomainName Optional Cognito Domain Name, if provided it will be used for Cognito Domain, and domainName will be used for the Elasticsearch Domain.
         * @return {@code this}
         */
        public Builder cognitoDomainName(java.lang.String cognitoDomainName) {
            this.cognitoDomainName = cognitoDomainName;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToElasticSearchAndKibanaProps#getCreateCloudWatchAlarms}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms.
         * @return {@code this}
         */
        public Builder createCloudWatchAlarms(java.lang.Boolean createCloudWatchAlarms) {
            this.createCloudWatchAlarms = createCloudWatchAlarms;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToElasticSearchAndKibanaProps#getDomainEndpointEnvironmentVariableName}
         * @param domainEndpointEnvironmentVariableName Optional Name for the ElasticSearch domain endpoint environment variable set for the Lambda function.
         * @return {@code this}
         */
        public Builder domainEndpointEnvironmentVariableName(java.lang.String domainEndpointEnvironmentVariableName) {
            this.domainEndpointEnvironmentVariableName = domainEndpointEnvironmentVariableName;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToElasticSearchAndKibanaProps#getEsDomainProps}
         * @param esDomainProps Optional user provided props to override the default props for the Elasticsearch Service.
         * @return {@code this}
         */
        public Builder esDomainProps(software.amazon.awscdk.services.elasticsearch.CfnDomainProps esDomainProps) {
            this.esDomainProps = esDomainProps;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToElasticSearchAndKibanaProps#getExistingLambdaObj}
         * @param existingLambdaObj Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
         * @return {@code this}
         */
        public Builder existingLambdaObj(software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.existingLambdaObj = existingLambdaObj;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToElasticSearchAndKibanaProps#getLambdaFunctionProps}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function.
         * @return {@code this}
         */
        public Builder lambdaFunctionProps(software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.lambdaFunctionProps = lambdaFunctionProps;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LambdaToElasticSearchAndKibanaProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @Override
        public LambdaToElasticSearchAndKibanaProps build() {
            return new Jsii$Proxy(domainName, cognitoDomainName, createCloudWatchAlarms, domainEndpointEnvironmentVariableName, esDomainProps, existingLambdaObj, lambdaFunctionProps);
        }
    }

    /**
     * An implementation for {@link LambdaToElasticSearchAndKibanaProps}
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LambdaToElasticSearchAndKibanaProps {
        private final java.lang.String domainName;
        private final java.lang.String cognitoDomainName;
        private final java.lang.Boolean createCloudWatchAlarms;
        private final java.lang.String domainEndpointEnvironmentVariableName;
        private final software.amazon.awscdk.services.elasticsearch.CfnDomainProps esDomainProps;
        private final software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.domainName = software.amazon.jsii.Kernel.get(this, "domainName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.cognitoDomainName = software.amazon.jsii.Kernel.get(this, "cognitoDomainName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.createCloudWatchAlarms = software.amazon.jsii.Kernel.get(this, "createCloudWatchAlarms", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.domainEndpointEnvironmentVariableName = software.amazon.jsii.Kernel.get(this, "domainEndpointEnvironmentVariableName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.esDomainProps = software.amazon.jsii.Kernel.get(this, "esDomainProps", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.elasticsearch.CfnDomainProps.class));
            this.existingLambdaObj = software.amazon.jsii.Kernel.get(this, "existingLambdaObj", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
            this.lambdaFunctionProps = software.amazon.jsii.Kernel.get(this, "lambdaFunctionProps", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.FunctionProps.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String domainName, final java.lang.String cognitoDomainName, final java.lang.Boolean createCloudWatchAlarms, final java.lang.String domainEndpointEnvironmentVariableName, final software.amazon.awscdk.services.elasticsearch.CfnDomainProps esDomainProps, final software.amazon.awscdk.services.lambda.Function existingLambdaObj, final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.domainName = java.util.Objects.requireNonNull(domainName, "domainName is required");
            this.cognitoDomainName = cognitoDomainName;
            this.createCloudWatchAlarms = createCloudWatchAlarms;
            this.domainEndpointEnvironmentVariableName = domainEndpointEnvironmentVariableName;
            this.esDomainProps = esDomainProps;
            this.existingLambdaObj = existingLambdaObj;
            this.lambdaFunctionProps = lambdaFunctionProps;
        }

        @Override
        public final java.lang.String getDomainName() {
            return this.domainName;
        }

        @Override
        public final java.lang.String getCognitoDomainName() {
            return this.cognitoDomainName;
        }

        @Override
        public final java.lang.Boolean getCreateCloudWatchAlarms() {
            return this.createCloudWatchAlarms;
        }

        @Override
        public final java.lang.String getDomainEndpointEnvironmentVariableName() {
            return this.domainEndpointEnvironmentVariableName;
        }

        @Override
        public final software.amazon.awscdk.services.elasticsearch.CfnDomainProps getEsDomainProps() {
            return this.esDomainProps;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
            return this.existingLambdaObj;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
            return this.lambdaFunctionProps;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("domainName", om.valueToTree(this.getDomainName()));
            if (this.getCognitoDomainName() != null) {
                data.set("cognitoDomainName", om.valueToTree(this.getCognitoDomainName()));
            }
            if (this.getCreateCloudWatchAlarms() != null) {
                data.set("createCloudWatchAlarms", om.valueToTree(this.getCreateCloudWatchAlarms()));
            }
            if (this.getDomainEndpointEnvironmentVariableName() != null) {
                data.set("domainEndpointEnvironmentVariableName", om.valueToTree(this.getDomainEndpointEnvironmentVariableName()));
            }
            if (this.getEsDomainProps() != null) {
                data.set("esDomainProps", om.valueToTree(this.getEsDomainProps()));
            }
            if (this.getExistingLambdaObj() != null) {
                data.set("existingLambdaObj", om.valueToTree(this.getExistingLambdaObj()));
            }
            if (this.getLambdaFunctionProps() != null) {
                data.set("lambdaFunctionProps", om.valueToTree(this.getLambdaFunctionProps()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-solutions-constructs/aws-lambda-elasticsearch-kibana.LambdaToElasticSearchAndKibanaProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LambdaToElasticSearchAndKibanaProps.Jsii$Proxy that = (LambdaToElasticSearchAndKibanaProps.Jsii$Proxy) o;

            if (!domainName.equals(that.domainName)) return false;
            if (this.cognitoDomainName != null ? !this.cognitoDomainName.equals(that.cognitoDomainName) : that.cognitoDomainName != null) return false;
            if (this.createCloudWatchAlarms != null ? !this.createCloudWatchAlarms.equals(that.createCloudWatchAlarms) : that.createCloudWatchAlarms != null) return false;
            if (this.domainEndpointEnvironmentVariableName != null ? !this.domainEndpointEnvironmentVariableName.equals(that.domainEndpointEnvironmentVariableName) : that.domainEndpointEnvironmentVariableName != null) return false;
            if (this.esDomainProps != null ? !this.esDomainProps.equals(that.esDomainProps) : that.esDomainProps != null) return false;
            if (this.existingLambdaObj != null ? !this.existingLambdaObj.equals(that.existingLambdaObj) : that.existingLambdaObj != null) return false;
            return this.lambdaFunctionProps != null ? this.lambdaFunctionProps.equals(that.lambdaFunctionProps) : that.lambdaFunctionProps == null;
        }

        @Override
        public final int hashCode() {
            int result = this.domainName.hashCode();
            result = 31 * result + (this.cognitoDomainName != null ? this.cognitoDomainName.hashCode() : 0);
            result = 31 * result + (this.createCloudWatchAlarms != null ? this.createCloudWatchAlarms.hashCode() : 0);
            result = 31 * result + (this.domainEndpointEnvironmentVariableName != null ? this.domainEndpointEnvironmentVariableName.hashCode() : 0);
            result = 31 * result + (this.esDomainProps != null ? this.esDomainProps.hashCode() : 0);
            result = 31 * result + (this.existingLambdaObj != null ? this.existingLambdaObj.hashCode() : 0);
            result = 31 * result + (this.lambdaFunctionProps != null ? this.lambdaFunctionProps.hashCode() : 0);
            return result;
        }
    }
}

==> lambdaelasticsearchkibana-1.123.0-sources.jar: software/amazon/awsconstructs/services/lambdaelasticsearchkibana/LambdaToElasticSearchAndKibanaProps.java <==
package software.amazon.awsconstructs.services.lambdaelasticsearchkibana;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-21T01:42:13.076Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdaelasticsearchkibana.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-elasticsearch-kibana.LambdaToElasticSearchAndKibanaProps")
@software.amazon.jsii.Jsii.Proxy(LambdaToElasticSearchAndKibanaProps.Jsii$Proxy.class)
public interface LambdaToElasticSearchAndKibanaProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Cognito & ES Domain Name.
     * <p>
     * Default: - None
     */
    @org.jetbrains.annotations.NotNull java.lang.String getDomainName();

    /**
     * Optional Cognito Domain Name, if provided it will be used for Cognito Domain, and domainName will be used for the Elasticsearch Domain.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable java.lang.String getCognitoDomainName() {
        return null;
    }

    /**
     * Whether to create recommended CloudWatch alarms.
     * <p>
     * Default: - Alarms are created
     */
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getCreateCloudWatchAlarms() {
        return null;
    }

    /**
     * Optional Name for the ElasticSearch domain endpoint environment variable set for the Lambda function.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable java.lang.String getDomainEndpointEnvironmentVariableName() {
        return null;
    }

    /**
     * Optional user provided props to override the default props for the Elasticsearch Service.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.elasticsearch.CfnDomainProps getEsDomainProps() {
        return null;
    }

    /**
     * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
        return null;
    }

    /**
     * User provided props to override the default props for the Lambda function.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LambdaToElasticSearchAndKibanaProps}
     */
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LambdaToElasticSearchAndKibanaProps}
     */
    public static final class Builder implements software.amazon.jsii.Builder<LambdaToElasticSearchAndKibanaProps> {
        private java.lang.String domainName;
        private java.lang.String cognitoDomainName;
        private java.lang.Boolean createCloudWatchAlarms;
        private java.lang.String domainEndpointEnvironmentVariableName;
        private software.amazon.awscdk.services.elasticsearch.CfnDomainProps esDomainProps;
        private software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;

        /**
         * Sets the value of {@link LambdaToElasticSearchAndKibanaProps#getDomainName}
         * @param domainName Cognito & ES Domain Name. This parameter is required.
         * @return {@code this}
         */
        public Builder domainName(java.lang.String domainName) {
            this.domainName = domainName;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToElasticSearchAndKibanaProps#getCognitoDomainName}
         * @param cognitoDomainName Optional Cognito Domain Name, if provided it will be used for Cognito Domain, and domainName will be used for the Elasticsearch Domain.
         * @return {@code this}
         */
        public Builder cognitoDomainName(java.lang.String cognitoDomainName) {
            this.cognitoDomainName = cognitoDomainName;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToElasticSearchAndKibanaProps#getCreateCloudWatchAlarms}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms.
         * @return {@code this}
         */
        public Builder createCloudWatchAlarms(java.lang.Boolean createCloudWatchAlarms) {
            this.createCloudWatchAlarms = createCloudWatchAlarms;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToElasticSearchAndKibanaProps#getDomainEndpointEnvironmentVariableName}
         * @param domainEndpointEnvironmentVariableName Optional Name for the ElasticSearch domain endpoint environment variable set for the Lambda function.
         * @return {@code this}
         */
        public Builder domainEndpointEnvironmentVariableName(java.lang.String domainEndpointEnvironmentVariableName) {
            this.domainEndpointEnvironmentVariableName = domainEndpointEnvironmentVariableName;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToElasticSearchAndKibanaProps#getEsDomainProps}
         * @param esDomainProps Optional user provided props to override the default props for the Elasticsearch Service.
         * @return {@code this}
         */
        public Builder esDomainProps(software.amazon.awscdk.services.elasticsearch.CfnDomainProps esDomainProps) {
            this.esDomainProps = esDomainProps;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToElasticSearchAndKibanaProps#getExistingLambdaObj}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * @return {@code this}
         */
        public Builder existingLambdaObj(software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.existingLambdaObj = existingLambdaObj;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToElasticSearchAndKibanaProps#getLambdaFunctionProps}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function.
         * @return {@code this}
         */
        public Builder lambdaFunctionProps(software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.lambdaFunctionProps = lambdaFunctionProps;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LambdaToElasticSearchAndKibanaProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @Override
        public LambdaToElasticSearchAndKibanaProps build() {
            return new Jsii$Proxy(domainName, cognitoDomainName, createCloudWatchAlarms, domainEndpointEnvironmentVariableName, esDomainProps, existingLambdaObj, lambdaFunctionProps);
        }
    }

    /**
     * An implementation for {@link LambdaToElasticSearchAndKibanaProps}
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LambdaToElasticSearchAndKibanaProps {
        private final java.lang.String domainName;
        private final java.lang.String cognitoDomainName;
        private final java.lang.Boolean createCloudWatchAlarms;
        private final java.lang.String domainEndpointEnvironmentVariableName;
        private final software.amazon.awscdk.services.elasticsearch.CfnDomainProps esDomainProps;
        private final software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.domainName = software.amazon.jsii.Kernel.get(this, "domainName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.cognitoDomainName = software.amazon.jsii.Kernel.get(this, "cognitoDomainName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.createCloudWatchAlarms = software.amazon.jsii.Kernel.get(this, "createCloudWatchAlarms", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.domainEndpointEnvironmentVariableName = software.amazon.jsii.Kernel.get(this, "domainEndpointEnvironmentVariableName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.esDomainProps = software.amazon.jsii.Kernel.get(this, "esDomainProps", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.elasticsearch.CfnDomainProps.class));
            this.existingLambdaObj = software.amazon.jsii.Kernel.get(this, "existingLambdaObj", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
            this.lambdaFunctionProps = software.amazon.jsii.Kernel.get(this, "lambdaFunctionProps", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.FunctionProps.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String domainName, final java.lang.String cognitoDomainName, final java.lang.Boolean createCloudWatchAlarms, final java.lang.String domainEndpointEnvironmentVariableName, final software.amazon.awscdk.services.elasticsearch.CfnDomainProps esDomainProps, final software.amazon.awscdk.services.lambda.Function existingLambdaObj, final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.domainName = java.util.Objects.requireNonNull(domainName, "domainName is required");
            this.cognitoDomainName = cognitoDomainName;
            this.createCloudWatchAlarms = createCloudWatchAlarms;
            this.domainEndpointEnvironmentVariableName = domainEndpointEnvironmentVariableName;
            this.esDomainProps = esDomainProps;
            this.existingLambdaObj = existingLambdaObj;
            this.lambdaFunctionProps = lambdaFunctionProps;
        }

        @Override
        public final java.lang.String getDomainName() {
            return this.domainName;
        }

        @Override
        public final java.lang.String getCognitoDomainName() {
            return this.cognitoDomainName;
        }

        @Override
        public final java.lang.Boolean getCreateCloudWatchAlarms() {
            return this.createCloudWatchAlarms;
        }

        @Override
        public final java.lang.String getDomainEndpointEnvironmentVariableName() {
            return this.domainEndpointEnvironmentVariableName;
        }

        @Override
        public final software.amazon.awscdk.services.elasticsearch.CfnDomainProps getEsDomainProps() {
            return this.esDomainProps;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
            return this.existingLambdaObj;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
            return this.lambdaFunctionProps;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("domainName", om.valueToTree(this.getDomainName()));
            if (this.getCognitoDomainName() != null) {
                data.set("cognitoDomainName", om.valueToTree(this.getCognitoDomainName()));
            }
            if (this.getCreateCloudWatchAlarms() != null) {
                data.set("createCloudWatchAlarms", om.valueToTree(this.getCreateCloudWatchAlarms()));
            }
            if (this.getDomainEndpointEnvironmentVariableName() != null) {
                data.set("domainEndpointEnvironmentVariableName", om.valueToTree(this.getDomainEndpointEnvironmentVariableName()));
            }
            if (this.getEsDomainProps() != null) {
                data.set("esDomainProps", om.valueToTree(this.getEsDomainProps()));
            }
            if (this.getExistingLambdaObj() != null) {
                data.set("existingLambdaObj", om.valueToTree(this.getExistingLambdaObj()));
            }
            if (this.getLambdaFunctionProps() != null) {
                data.set("lambdaFunctionProps", om.valueToTree(this.getLambdaFunctionProps()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-solutions-constructs/aws-lambda-elasticsearch-kibana.LambdaToElasticSearchAndKibanaProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LambdaToElasticSearchAndKibanaProps.Jsii$Proxy that = (LambdaToElasticSearchAndKibanaProps.Jsii$Proxy) o;

            if (!domainName.equals(that.domainName)) return false;
            if (this.cognitoDomainName != null ? !this.cognitoDomainName.equals(that.cognitoDomainName) : that.cognitoDomainName != null) return false;
            if (this.createCloudWatchAlarms != null ? !this.createCloudWatchAlarms.equals(that.createCloudWatchAlarms) : that.createCloudWatchAlarms != null) return false;
            if (this.domainEndpointEnvironmentVariableName != null ? !this.domainEndpointEnvironmentVariableName.equals(that.domainEndpointEnvironmentVariableName) : that.domainEndpointEnvironmentVariableName != null) return false;
            if (this.esDomainProps != null ? !this.esDomainProps.equals(that.esDomainProps) : that.esDomainProps != null) return false;
            if (this.existingLambdaObj != null ? !this.existingLambdaObj.equals(that.existingLambdaObj) : that.existingLambdaObj != null) return false;
            return this.lambdaFunctionProps != null ? this.lambdaFunctionProps.equals(that.lambdaFunctionProps) : that.lambdaFunctionProps == null;
        }

        @Override
        public final int hashCode() {
            int result = this.domainName.hashCode();
            result = 31 * result + (this.cognitoDomainName != null ? this.cognitoDomainName.hashCode() : 0);
            result = 31 * result + (this.createCloudWatchAlarms != null ? this.createCloudWatchAlarms.hashCode() : 0);
            result = 31 * result + (this.domainEndpointEnvironmentVariableName != null ? this.domainEndpointEnvironmentVariableName.hashCode() : 0);
            result = 31 * result + (this.esDomainProps != null ? this.esDomainProps.hashCode() : 0);
            result = 31 * result + (this.existingLambdaObj != null ? this.existingLambdaObj.hashCode() : 0);
            result = 31 * result + (this.lambdaFunctionProps != null ? this.lambdaFunctionProps.hashCode() : 0);
            return result;
        }
    }
}
